@@ -20,9 +20,6 @@
 
 #include "bugzillalib.h"
 
-#include "drkonqi_globals.h"
-#include "findconfigdatajob.h"
-
 #include <QtCore/QTextStream>
 #include <QtCore/QByteArray>
 #include <QtCore/QString>
@@ -34,15 +31,13 @@
 
 #include <KIO/Job>
 #include <KUrl>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KDebug>
 
-static const char bugtrackerBKOBaseUrl[] = KDE_BUGZILLA_URL;
 
 static const char columns[] = "bug_severity,priority,bug_status,product,short_desc,resolution";
 
 //Bugzilla URLs
-static const char loginUrl[] = "index.cgi";
 static const char searchUrl[] =
         "buglist.cgi?query_format=advanced&order=Importance&ctype=csv"
         "&product=%1"
@@ -54,32 +49,37 @@ static const char searchUrl[] =
 static const char showBugUrl[] = "show_bug.cgi?id=%1";
 static const char fetchBugUrl[] = "show_bug.cgi?id=%1&ctype=xml";
 
+static inline Component buildComponent(const QVariantMap& map);
+static inline Version buildVersion(const QVariantMap& map);
+static inline Product buildProduct(const QVariantMap& map);
+
 //BEGIN BugzillaManager
 
-BugzillaManager::BugzillaManager(QObject *parent):
-        QObject(parent),
-        m_logged(false),
-        m_searchJob(0)
+BugzillaManager::BugzillaManager(const QString &bugTrackerUrl, QObject *parent)
+        : QObject(parent)
+        , m_bugTrackerUrl(bugTrackerUrl)
+        , m_logged(false)
+        , m_searchJob(0)
 {
-    m_bugTrackerUrl = bugtrackerBKOBaseUrl;
-    m_xmlRpcClient = new KXmlRpc::Client(KUrl(KDE_BUGZILLA_URL "xmlrpc.cgi"), this);
+    m_xmlRpcClient = new KXmlRpc::Client(KUrl(m_bugTrackerUrl + "xmlrpc.cgi"), this);
     m_xmlRpcClient->setUserAgent(QLatin1String("DrKonqi"));
 }
 
 //BEGIN Login methods
-void BugzillaManager::tryLogin()
+void BugzillaManager::tryLogin(const QString& username, const QString& password)
 {
-    if (!m_logged) {
-        QMap<QString, QVariant> args;
-        args.insert(QLatin1String("login"), m_username);
-        args.insert(QLatin1String("password"), m_password);
-        args.insert(QLatin1String("remember"), false);
+    m_username = username;
+    m_logged = false;
 
-        m_xmlRpcClient->call(QLatin1String("User.login"), args,
-                this, SLOT(callMessage(QList<QVariant>,QVariant)),
-                this, SLOT(callFault(int,QString,QVariant)),
-                QString::fromAscii("login"));
-    }
+    QMap<QString, QVariant> args;
+    args.insert(QLatin1String("login"), username);
+    args.insert(QLatin1String("password"), password);
+    args.insert(QLatin1String("remember"), false);
+
+    m_xmlRpcClient->call(QLatin1String("User.login"), args,
+            this, SLOT(callMessage(QList<QVariant>,QVariant)),
+            this, SLOT(callFault(int,QString,QVariant)),
+            QString::fromAscii("login"));
 }
 
 bool BugzillaManager::getLogged() const
@@ -87,13 +87,6 @@ bool BugzillaManager::getLogged() const
     return m_logged;
 }
 
-void BugzillaManager::setLoginData(const QString & _username, const QString & _password)
-{
-    m_username = _username;
-    m_password = _password;
-    m_logged = false;
-}
-
 QString BugzillaManager::getUsername() const
 {
     return m_username;
@@ -162,12 +155,12 @@ void BugzillaManager::sendReport(const BugReport & report)
 }
 
 void BugzillaManager::attachTextToReport(const QString & text, const QString & filename,
-    const QString & description, int bugId, const QString & comment)
+    const QString & summary, int bugId, const QString & comment)
 {
     QMap<QString, QVariant> args;
     args.insert(QLatin1String("ids"), QVariantList() << bugId);
     args.insert(QLatin1String("file_name"), filename);
-    args.insert(QLatin1String("summary"), description);
+    args.insert(QLatin1String("summary"), summary);
     args.insert(QLatin1String("comment"), comment);
     args.insert(QLatin1String("content_type"), QString::fromAscii("text/plain"));
 
@@ -195,13 +188,25 @@ void BugzillaManager::addMeToCC(int bugId)
             QString::fromAscii("Bug.update.cc"));
 }
 
-void BugzillaManager::checkVersionsForProduct(const QString & product)
+void BugzillaManager::fetchProductInfo(const QString & product)
 {
-    FindConfigDataJob *job = new FindConfigDataJob(product, KUrl(m_bugTrackerUrl));
-    connect(job, SIGNAL(finished(KJob*)) , this, SLOT(checkVersionJobFinished(KJob*)));
-    job->start();
+    QMap<QString, QVariant> args;
+
+    args.insert("names", (QStringList() << product) ) ;
+
+    QStringList includeFields;
+    // currently we only need these informations
+    includeFields << "name" << "is_active" << "components" << "versions";
+
+    args.insert("include_fields", includeFields) ;
+
+    m_xmlRpcClient->call(QLatin1String("Product.get"), args,
+            this, SLOT(callMessage(QList<QVariant>,QVariant)),
+            this, SLOT(callFault(int,QString,QVariant)),
+            QString::fromAscii("Product.get.versions"));
 }
 
+
 //END Bugzilla Action methods
 
 //BEGIN Misc methods
@@ -210,11 +215,6 @@ QString BugzillaManager::urlForBug(int bug_number) const
     return QString(m_bugTrackerUrl) + QString(showBugUrl).arg(bug_number);
 }
 
-void BugzillaManager::setCustomBugtrackerUrl(const QString & customUrl)
-{
-    m_bugTrackerUrl = customUrl;
-}
-
 void BugzillaManager::stopCurrentSearch()
 {
     if (m_searchJob) { //Stop previous searchJob
@@ -271,13 +271,59 @@ void BugzillaManager::searchBugsJobFinished(KJob * job)
     m_searchJob = 0;
 }
 
-void BugzillaManager::checkVersionJobFinished(KJob * job)
+static inline Component buildComponent(const QVariantMap& map)
 {
-    if (!job->error()) {
-        FindConfigDataJob *checkVersionJob = static_cast<FindConfigDataJob*>(job);
-        emit checkVersionsForProductFinished(checkVersionJob->data(FindConfigDataJob::Version));
+    QString name = map.value("name").toString();
+    bool active = map.value("is_active").toBool();
+
+    return Component(name, active);
+}
+
+static inline Version buildVersion(const QVariantMap& map)
+{
+    QString name = map.value("name").toString();
+    bool active = map.value("is_active").toBool();
+
+    return Version(name, active);
+}
+
+static inline Product buildProduct(const QVariantMap& map)
+{
+    QString name = map.value("name").toString();
+    bool active = map.value("is_active").toBool();
+
+    Product product(name, active);
+
+    QVariantList components = map.value("components").toList();
+    foreach (const QVariant& c, components) {
+        Component component = buildComponent(c.toMap());
+        product.addComponent(component);
+
+    }
+
+    QVariantList versions = map.value("versions").toList();
+    foreach (const QVariant& v, versions) {
+        Version version = buildVersion(v.toMap());
+        product.addVersion(version);
+    }
+
+    return product;
+}
+
+void BugzillaManager::fetchProductInfoFinished(const QVariantMap & map)
+{
+    QList<Product> products;
+
+    QVariantList plist = map.value("products").toList();
+    foreach (const QVariant& p, plist) {
+        Product product = buildProduct(p.toMap());
+        products.append(product);
+    }
+
+    if ( products.size() > 0 ) {
+        emit productInfoFetched(products.at(0));
     } else {
-        emit checkVersionsForProductError();
+        emit productInfoError();
     }
 }
 
@@ -290,6 +336,9 @@ void BugzillaManager::callMessage(const QList<QVariant> & result, const QVariant
     if (id.toString() == QLatin1String("login")) {
         m_logged = true;
         Q_EMIT loginFinished(true);
+    } else if (id.toString() == QLatin1String("Product.get.versions")) {
+        QVariantMap map = result.at(0).toMap();
+        fetchProductInfoFinished(map);
     } else if (id.toString() == QLatin1String("Bug.create")) {
         QVariantMap map = result.at(0).toMap();
         int bug_id = map.value(QLatin1String("id")).toInt();
@@ -332,6 +381,7 @@ void BugzillaManager::callFault(int errorCode, const QString & errorString, cons
         }
     } else if (id.toString() == QLatin1String("Bug.create")) {
         switch (errorCode) {
+        case 51:  //invalid object (one example is invalid platform value)
         case 105: //invalid component
         case 106: //invalid product
             Q_EMIT sendReportErrorInvalidValues();
@@ -431,7 +481,6 @@ BugReport BugReportXMLParser::parse()
         m_valid = d2.isNull();
 
         if (m_valid) {
-            m_valid = true;
             report.setValid(true);
 
             //Get basic fields
